Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2968)

Unified Diff: blimp/client/public/blimp_contents_observer.h

Issue 2058263002: Tied up BlimpNavigationController to NavigationFeature (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@blimp_core
Patch Set: Changed BlimpContentsObserver's navigation methods to OnNavigationStateChanged Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: blimp/client/public/blimp_contents_observer.h
diff --git a/blimp/client/public/blimp_contents_observer.h b/blimp/client/public/blimp_contents_observer.h
index c980833eaed245072e85d91a33b7637092d7ff9f..a4b7337c32b4642eac62475f14fafbdeff1845fc 100644
--- a/blimp/client/public/blimp_contents_observer.h
+++ b/blimp/client/public/blimp_contents_observer.h
@@ -17,8 +17,8 @@ class BlimpContentsObserver {
public:
virtual ~BlimpContentsObserver() = default;
- // Invoked when the URL of the BlimpContents is changes.
- virtual void OnURLUpdated(const GURL& url) {}
+ // Invoked when the navigation state of the BlimpContents has changed.
+ virtual void OnNavigationStateChanged() {}
protected:
BlimpContentsObserver() {}

Powered by Google App Engine
This is Rietveld 408576698